# BMP280

Bosch Digital Pressure Sensor

- Device address 119
- Address type 7-bit

### Addr 136 16-bytes Read-only | # Digital Temperature Compensation 1 ## Used for Celcius conversion
### Addr 138 16-bytes Read-only Signed value | # Digital Temperature Compensation 2 ## Used for Celcius conversion
### Addr 140 16-bytes Read-only Signed value | # Digital Temperature Compensation 3 ## Used for Celcius conversion
### Addr 142 16-bytes Read-only | # Digital Pressure Compensation 1 ## Used for Pascals conversion
### Addr 144 16-bytes Read-only Signed value | # Digital Pressure Compensation 2 ## Used for Pascals conversion
### Addr 146 16-bytes Read-only Signed value | # Digital Pressure Compensation 3 ## Used for Pascals conversion
### Addr 148 16-bytes Read-only Signed value | # Digital Pressure Compensation 4 ## Used for Pascals conversion
### Addr 150 16-bytes Read-only Signed value | # Digital Pressure Compensation 5 ## Used for Pascals conversion
### Addr 152 16-bytes Read-only Signed value | # Digital Pressure Compensation 6 ## Used for Pascals conversion
### Addr 154 16-bytes Read-only Signed value | # Digital Pressure Compensation 7 ## Used for Pascals conversion
### Addr 156 16-bytes Read-only Signed value | # Digital Pressure Compensation 8 ## Used for Pascals conversion
### Addr 158 16-bytes Read-only Signed value | # Digital Pressure Compensation 9 ## Used for Pascals conversion
### Addr 247 8-bytes Read-only | # Pressure MSB ## Part 1 of Pressure |
### Addr 248 8-bytes Read-only | # Pressure LSB ## Part 2 of Pressure |
### Addr 249 8-bytes Read-only | # Pressure XLSB ## Part 3 of Pressure |
### Addr 250 8-bytes Read-only | # Temperature MSB ## Part 1 of temperature |
### Addr 251 8-bytes Read-only | # Temperature LSB ## Part 2 of temperature |
### Addr 252 8-bytes Read-only | # Temperature XLSB ## Final part of temperature |

## Functions

- pressure.asHpa - Reads the atmospheric pressure
- pressure.asRaw - Reads the atmospheric pressure
- temperature.asCelsius - Reads the temperature
- temperature.asRaw - Reads the temperature